@@ -389,8 +389,6 @@ TotalSpellTimeExceedingThreshold <- function(data, threshold, spell, op = '>',
         warning("Parameter 'dates' must have named dimensions if 'start' and ",
                 "'end' are not NULL. All data will be used.")
       }
-      data <- SelectPeriodOnData(data, dates, start, end, 
-                                 time_dim = time_dim, ncores = ncores)
     }
   }
 
