@@ -119,7 +119,7 @@ CST_TotalTimeExceedingThreshold <- function(data, threshold, op = '>',
                                        ncores = ncores)
   data$data <- total
   data$dims <- dim(total)
-  data$coords[[time_dim]] <- NULL
+  data$coords[[time_dim]] <- 1 : length(data$dims[[time_dim]])
 
   if (!is.null(Dates)) {
     if (!is.null(start) && !is.null(end)) {
@@ -134,10 +134,10 @@ CST_TotalTimeExceedingThreshold <- function(data, threshold, op = '>',
       # Create time_bounds
       time_bounds <- NULL
       time_bounds$start <- ClimProjDiags::Subset(x = Dates, along = time_dim, 
-                                                 indices = 1, drop = 'selected')
+                                                 indices = 1, drop = FALSE)
       time_bounds$end <- ClimProjDiags::Subset(x = Dates, along = time_dim, 
                                                indices = dim(Dates)[time_dim], 
-                                               drop = 'selected')
+                                               drop = FALSE)
 
       # Add Dates in attrs
       data$attrs$Dates <- time_bounds$start
@@ -221,6 +221,7 @@ CST_TotalTimeExceedingThreshold <- function(data, threshold, op = '>',
 #'                                   start = list(21, 4), end = list(21, 6))
 #'
 #'@import multiApply
+#'@importFrom stats setNames
 #'@export
 TotalTimeExceedingThreshold <- function(data, threshold, op = '>',
                                         dates = NULL, start = NULL, end = NULL,
@@ -431,6 +432,7 @@ TotalTimeExceedingThreshold <- function(data, threshold, op = '>',
                      ncores = ncores)$output1
     }
   }
+  dim(total) <- c(dim(total), setNames(1, time_dim))
   return(total)
 }
 
@@ -467,4 +469,4 @@ TotalTimeExceedingThreshold <- function(data, threshold, op = '>',
     }
   }
   return(res)
-}
\ No newline at end of file
+}
